@@ -9,12 +9,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+from openstack.common import tag
 from openstack.network.v2 import _base
 from openstack import resource
 
 
-class SecurityGroup(_base.NetworkResource, resource.TagMixin):
+class SecurityGroup(_base.NetworkResource, tag.TagMixin):
     resource_key = 'security_group'
     resources_key = 'security_groups'
     base_path = '/security-groups'
@@ -27,9 +27,9 @@ class SecurityGroup(_base.NetworkResource, resource.TagMixin):
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
-        'description', 'fields', 'name', 'project_id', 'tenant_id',
-        'revision_number', 'sort_dir', 'sort_key',
-        **resource.TagMixin._tag_query_parameters
+        'description', 'fields', 'id', 'name', 'stateful', 'project_id',
+        'tenant_id', 'revision_number', 'sort_dir', 'sort_key',
+        **tag.TagMixin._tag_query_parameters
     )
 
     # Properties
@@ -39,6 +39,8 @@ class SecurityGroup(_base.NetworkResource, resource.TagMixin):
     description = resource.Body('description')
     #: The security group name.
     name = resource.Body('name')
+    #: Whether the security group is stateful or not.
+    stateful = resource.Body('stateful')
     #: The ID of the project this security group is associated with.
     project_id = resource.Body('project_id')
     #: A list of
@@ -46,6 +48,6 @@ class SecurityGroup(_base.NetworkResource, resource.TagMixin):
     #: objects. *Type: list*
     security_group_rules = resource.Body('security_group_rules', type=list)
     #: The ID of the project this security group is associated with.
-    tenant_id = resource.Body('tenant_id')
+    tenant_id = resource.Body('tenant_id', deprecated=True)
     #: Timestamp when the security group was last updated.
     updated_at = resource.Body('updated_at')
