@@ -10,24 +10,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import os
-
 from openstack.tests.functional import base
 
 
 class BaseBlockStorageTest(base.BaseFunctionalTest):
 
-    @classmethod
-    def setUpClass(cls):
-        super(BaseBlockStorageTest, cls).setUpClass()
-        cls._wait_for_timeout = int(os.getenv(
-            'OPENSTACKSDK_FUNC_TEST_TIMEOUT_BLOCK_STORAGE',
-            cls._wait_for_timeout))
+    _wait_for_timeout_key = 'OPENSTACKSDK_FUNC_TEST_TIMEOUT_BLOCK_STORAGE'
 
     def setUp(self):
         super(BaseBlockStorageTest, self).setUp()
         self._set_user_cloud(block_storage_api_version='3')
-        self._set_operator_cloud(block_storage_api_version='3')
-
-        if not self.user_cloud.has_service('block-storage'):
+        if not self.user_cloud.has_service('block-storage', '3'):
             self.skipTest('block-storage service not supported by cloud')
